# Third Party Notices

The newrelic-lambda-cli uses source code from third party libraries which carry their own copyright notices and license terms. These notices are provided below.

 the event that a required notice is missing or incorrect, please notify us by e-mailing open-source@newrelic.com.

r any licenses that require the disclosure of source code, the source code can be found at [newrelic-lambda-cli](https://github.com/newrelic/newrelic-lambda-cli).

## Content

**[dependencies](#dependencies)**

**[devDependencies](#devdependencies)**

## Dependencies

| Name            | Version   | License                                                      |
|-----------------|-----------|--------------------------------------------------------------|
| Click           | 7.0       | BSD                                                          |
| Rx              | 1.6.1     | Apache License                                               |
| boto3           | 1.10.22   | Apache License 2.0                                           |
| botocore        | 1.13.22   | Apache License 2.0                                           |
| certifi         | 2019.9.11 | MPL-2.0                                                      |
| chardet         | 3.0.4     | LGPL                                                         |
| colorama        | 0.4.1     | BSD                                                          |
| docutils        | 0.15.2    | public domain, Python, 2-Clause BSD, GPL 3 (see COPYING.txt) |
| gql             | 0.1.0     | MIT                                                          |
| graphql-core    | 2.2.1     | MIT                                                          |
| idna            | 2.8       | BSD-like                                                     |
| jmespath        | 0.9.4     | MIT                                                          |
| promise         | 2.2.1     | MIT                                                          |
| python-dateutil | 2.8.0     | Dual License                                                 |
| requests        | 2.22.0    | Apache 2.0                                                   |
| s3transfer      | 0.2.1     | Apache License 2.0                                           |
| six             | 1.13.0    | MIT                                                          |
| tabulate        | 0.8.6     | MIT                                                          |
| urllib3         | 1.25.7    | MIT                                                          |

## DevDependencies

| Name            | Version   | License                                                      |
|-----------------|-----------|--------------------------------------------------------------|
| Click           | 7.0       | BSD                                                          |
| Rx              | 1.6.1     | Apache License                                               |
| boto3           | 1.10.10   | Apache License 2.0                                           |
| botocore        | 1.13.10   | Apache License 2.0                                           |
| certifi         | 2019.9.11 | MPL-2.0                                                      |
| chardet         | 3.0.4     | LGPL                                                         |
| docutils        | 0.15.2    | public domain, Python, 2-Clause BSD, GPL 3 (see COPYING.txt) |
| gql             | 0.1.0     | MIT                                                          |
| graphql-core    | 2.2.1     | MIT                                                          |
| idna            | 2.8       | BSD-like                                                     |
| jmespath        | 0.9.4     | MIT                                                          |
| promise         | 2.2.1     | MIT                                                          |
| python-dateutil | 2.8.0     | Dual License                                                 |
| requests        | 2.22.0    | Apache 2.0                                                   |
| s3transfer      | 0.2.1     | Apache License 2.0                                           |
| six             | 1.13.0    | MIT                                                          |
| tabulate        | 0.8.5     | MIT                                                          |
| urllib3         | 1.25.6    | MIT                                                          |
